@@ -6,7 +6,7 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
-#include "../numa.h"
+#include <numa.h>
 #include <unistd.h>
 #include <errno.h>
 
@@ -122,4 +122,3 @@ int main(int argc, char **argv)
 
 	return errors > 0 ? 1 : 0;
 }
-
