@@ -6,7 +6,7 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
-#include "../numa.h"
+#include "numa.h"
 #include <unistd.h>
 #include <asm/unistd.h>
 
@@ -99,4 +99,3 @@ int main(int argc, char **argv)
 
 	return errors > 0 ? 1 : 0;
 }
-
